==> ftape-tools-1.08.tar.gz: ftape-tools-1.08/include/ftape/linux/zftape.h <==
#ifndef _ZFTAPE_H
#define _ZFTAPE_H

/*
 * Copyright (C) 1996-1998 Claus-Justus Heine.

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; see the file COPYING.  If not, write to
 the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

 *
 * $RCSfile: zftape.h,v $
 * $Revision: 1.3 $
 * $Date: 1999/08/31 10:07:44 $
 *
 *      Special ioctl and other global info for the zftape VFS
 *      interface for the QIC-40/80/3010/3020 floppy-tape driver for
 *      Linux.
 */

#define ZFTAPE_VERSION  "zftape for " FTAPE_VERSION

#include <linux/ftape.h>

#define ZFTAPE_LABEL       "Ftape - The Linux Floppy Tape Project!"

/* Bits of the minor device number that control the operation mode */

#ifndef ZFT_OBSOLETE
# define ZFT_MINOR_OP_MASK 0
#else

/* NOTE: all of these bits are considered OBSOLETE. In-kernel
 * compression isn't supported any longer, and the "raw mode" stuff is
 * controlled using an ioctl
 */
# define ZFT_Q80_MODE		(1 << 3) 
# define ZFT_RAW_MODE		(1 << 5)
# if defined(CONFIG_ZFT_COMPRESSOR) || defined(CONFIG_ZFT_COMPRESSOR_MODULE)
/* read-only compatibility with pre-ftape-4.x compressed volumes */
#  define ZFT_ZIP_MODE		(1 << 4)
#  define ZFT_MINOR_OP_MASK	(ZFT_Q80_MODE	| 	\
				 ZFT_ZIP_MODE	| 	\
				 ZFT_RAW_MODE)
# else
#  define ZFT_MINOR_OP_MASK	(ZFT_Q80_MODE	| 	\
				 ZFT_RAW_MODE)
# endif /* CONFIG_ZFT_COMPRESSOR || CONFIG_ZFT_COMPRESSOR_MODULE */

struct mtblksz {
	unsigned int mt_blksz;
};
# define MTIOC_ZFTAPE_GETBLKSZ _IOR('m', 104, struct mtblksz)
#endif /* ZFT_OBSOLETE */

/* valid bits of minor device number */
#define ZFT_MINOR_MASK		(FTAPE_SEL_MASK		|	\
				 ZFT_MINOR_OP_MASK	|	\
				 FTAPE_NO_REWIND)

#ifdef __KERNEL__

extern int zft_init(void);

extern inline __s64 zft_div_blksz(__s64 value, __u32 blk_sz)
{
	if (blk_sz == 1) {
		return value;
	} else {
		return (__s64)(((__u32)(value >> 10) + (blk_sz >> 10) - 1) 
			       / (blk_sz >> 10));
	} 
}

extern inline __s64 zft_mul_blksz(__s64 value, __u32 blk_sz)
{
	if (blk_sz == 1) {
		return value;
	} else {
		/*  if blk_sz != 1, then it is a multiple of 1024. In
		 *  this case, `value' will also fit into 32 bits.
		 * 
		 *  Actually, this limits the capacity to 42
		 *  bits. This is (2^32)*1024, roughly a thousand
		 *  times 2GB, or 3 Terabytes. Hopefully this is enough
		 */
		return(__s64)(((__u32)(value)*(blk_sz>>10))<<10);
	}
}

#endif

#endif

==> ftape-tools_1.09.2002.03.21.orig.tar.gz: ftape-tools-1.09.2002.03.21.orig/include/ftape/linux/zftape.h <==
#ifndef _ZFTAPE_H
#define _ZFTAPE_H

/*
 * Copyright (C) 1996-1998 Claus-Justus Heine.

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; see the file COPYING.  If not, write to
 the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

 *
 * $RCSfile: zftape.h,v $
 * $Revision: 1.4 $
 * $Date: 2000/07/20 16:29:04 $
 *
 *      Special ioctl and other global info for the zftape VFS
 *      interface for the QIC-40/80/3010/3020 floppy-tape driver for
 *      Linux.
 */

#define ZFTAPE_VERSION  "zftape for " FTAPE_VERSION

#include <linux/ftape.h>

#define ZFTAPE_LABEL       "Ftape - The Linux Floppy Tape Project!"

/* Bits of the minor device number that control the operation mode */

#ifndef CONFIG_ZFT_OBSOLETE
# define ZFT_MINOR_OP_MASK 0
#else

/* NOTE: all of these bits are considered OBSOLETE. In-kernel
 * compression isn't supported any longer, and the "raw mode" stuff is
 * controlled using an ioctl
 */
# define ZFT_Q80_MODE		(1 << 3) 
# define ZFT_RAW_MODE		(1 << 5)
# if defined(CONFIG_ZFT_COMPRESSOR) || defined(CONFIG_ZFT_COMPRESSOR_MODULE)
/* read-only compatibility with pre-ftape-4.x compressed volumes */
#  define ZFT_ZIP_MODE		(1 << 4)
#  define ZFT_MINOR_OP_MASK	(ZFT_Q80_MODE	| 	\
				 ZFT_ZIP_MODE	| 	\
				 ZFT_RAW_MODE)
# else
#  define ZFT_MINOR_OP_MASK	(ZFT_Q80_MODE	| 	\
				 ZFT_RAW_MODE)
# endif /* CONFIG_ZFT_COMPRESSOR || CONFIG_ZFT_COMPRESSOR_MODULE */

struct mtblksz {
	unsigned int mt_blksz;
};
# define MTIOC_ZFTAPE_GETBLKSZ _IOR('m', 104, struct mtblksz)
#endif /* CONFIG_ZFT_OBSOLETE */

/* valid bits of minor device number */
#define ZFT_MINOR_MASK		(FTAPE_SEL_MASK		|	\
				 ZFT_MINOR_OP_MASK	|	\
				 FTAPE_NO_REWIND)

#ifdef __KERNEL__

extern int zft_init(void);

extern inline __s64 zft_div_blksz(__s64 value, __u32 blk_sz)
{
	if (blk_sz == 1) {
		return value;
	} else {
		return (__s64)(((__u32)(value >> 10) + (blk_sz >> 10) - 1) 
			       / (blk_sz >> 10));
	} 
}

extern inline __s64 zft_mul_blksz(__s64 value, __u32 blk_sz)
{
	if (blk_sz == 1) {
		return value;
	} else {
		/*  if blk_sz != 1, then it is a multiple of 1024. In
		 *  this case, `value' will also fit into 32 bits.
		 * 
		 *  Actually, this limits the capacity to 42
		 *  bits. This is (2^32)*1024, roughly a thousand
		 *  times 2GB, or 3 Terabytes. Hopefully this is enough
		 */
		return(__s64)(((__u32)(value)*(blk_sz>>10))<<10);
	}
}

#endif

#endif
